@@ -15,6 +15,7 @@
 import pathlib
 from typing import Dict, Optional, Union, cast
 
+from playwright._impl._api_structures import TracingGroupLocation
 from playwright._impl._artifact import Artifact
 from playwright._impl._connection import ChannelOwner, from_nullable_channel
 from playwright._impl._helper import locals_to_params
@@ -25,7 +26,7 @@ class Tracing(ChannelOwner):
         self, parent: ChannelOwner, type: str, guid: str, initializer: Dict
     ) -> None:
         super().__init__(parent, type, guid, initializer)
-        self.mark_as_internal_type()
+        self._channel.mark_as_internal_type()
         self._include_sources: bool = False
         self._stacks_id: Optional[str] = None
         self._is_tracing: bool = False
@@ -131,3 +132,9 @@ class Tracing(ChannelOwner):
         if self._is_tracing:
             self._is_tracing = False
             self._connection.set_is_tracing(False)
+
+    async def group(self, name: str, location: TracingGroupLocation = None) -> None:
+        await self._channel.send("tracingGroup", locals_to_params(locals()))
+
+    async def group_end(self) -> None:
+        await self._channel.send("tracingGroupEnd")
